; $Id: ogg.def 14733 2008-04-14 21:27:06Z sping $
;
; ogg.def
;
LIBRARY
EXPORTS
;
oggpack_writeinit
oggpack_writetrunc
oggpack_writealign
oggpack_writecopy
oggpack_reset
oggpack_writeclear
oggpack_readinit
oggpack_write
oggpack_look
oggpack_look1
oggpack_adv
oggpack_adv1
oggpack_read
oggpack_read1
oggpack_bytes
oggpack_bits
oggpack_get_buffer
;
oggpackB_writeinit
oggpackB_writetrunc
oggpackB_writealign
oggpackB_writecopy
oggpackB_reset
oggpackB_writeclear
oggpackB_readinit
oggpackB_write
oggpackB_look
oggpackB_look1
oggpackB_adv
oggpackB_adv1
oggpackB_read
oggpackB_read1
oggpackB_bytes
oggpackB_bits
oggpackB_get_buffer
;
ogg_stream_packetin
ogg_stream_pageout
ogg_stream_flush
;
ogg_sync_init
ogg_sync_clear
ogg_sync_reset
ogg_sync_destroy
ogg_sync_buffer
ogg_sync_wrote
ogg_sync_pageseek
ogg_sync_pageout
ogg_stream_pagein
ogg_stream_packetout
ogg_stream_packetpeek
;
ogg_stream_init
ogg_stream_clear
ogg_stream_reset
ogg_stream_reset_serialno
ogg_stream_destroy
ogg_stream_eos
;
ogg_page_checksum_set
ogg_page_version
ogg_page_continued
ogg_page_bos
ogg_page_eos
ogg_page_granulepos
ogg_page_serialno
ogg_page_pageno
ogg_page_packets
ogg_packet_clear
                                                        

